@@ -2,7 +2,7 @@ use crate::backend::backend_type::BackendType;
 use crate::cli::args::BackendArg;
 use crate::cli::version::{ARCH, OS};
 use crate::cmd::CmdLineRunner;
-use crate::config::SETTINGS;
+use crate::config::Settings;
 use crate::file::TarOptions;
 use crate::http::HTTP;
 use crate::install_context::InstallContext;
@@ -122,14 +122,18 @@ impl Backend for AquaBackend {
         Ok(tv)
     }
 
-    async fn list_bin_paths(&self, tv: &ToolVersion) -> Result<Vec<PathBuf>> {
+    async fn list_bin_paths(
+        &self,
+        _config: &Arc<Config>,
+        tv: &ToolVersion,
+    ) -> Result<Vec<PathBuf>> {
         // TODO: instead of caching it would probably be better to create this as part of installation
         let cache = self
             .bin_path_caches
             .entry(tv.version.clone())
             .or_insert_with(|| {
                 CacheManagerBuilder::new(tv.cache_path().join("bin_paths.msgpack.z"))
-                    .with_fresh_duration(SETTINGS.fetch_remote_versions_cache())
+                    .with_fresh_duration(Settings::get().fetch_remote_versions_cache())
                     .build()
             });
         let install_path = tv.install_path();
@@ -362,7 +366,7 @@ impl AquaBackend {
         v: &str,
         filename: &str,
     ) -> Result<()> {
-        if !SETTINGS.aqua.slsa {
+        if !Settings::get().aqua.slsa {
             return Ok(());
         }
         if let Some(minisign) = &pkg.minisign {
@@ -420,7 +424,7 @@ impl AquaBackend {
         v: &str,
         filename: &str,
     ) -> Result<()> {
-        if !SETTINGS.aqua.slsa {
+        if !Settings::get().aqua.slsa {
             return Ok(());
         }
         if let Some(slsa) = &pkg.slsa_provenance {
@@ -502,7 +506,7 @@ impl AquaBackend {
         tv: &ToolVersion,
         checksum_path: &Path,
     ) -> Result<()> {
-        if !SETTINGS.aqua.cosign {
+        if !Settings::get().aqua.cosign {
             return Ok(());
         }
         if let Some(cosign) = pkg.checksum.as_ref().and_then(|c| c.cosign.as_ref()) {
@@ -543,7 +547,12 @@ impl AquaBackend {
                 for opt in cosign.opts(pkg, v)? {
                     cmd = cmd.arg(opt);
                 }
-                for arg in SETTINGS.aqua.cosign_extra_args.clone().unwrap_or_default() {
+                for arg in Settings::get()
+                    .aqua
+                    .cosign_extra_args
+                    .clone()
+                    .unwrap_or_default()
+                {
                     cmd = cmd.arg(arg);
                 }
                 cmd = cmd.with_pr(&ctx.pr);
