@@ -20,17 +20,17 @@ enum Commands {
 }
 
 impl Commands {
-    pub fn run(self) -> Result<()> {
+    pub async fn run(self) -> Result<()> {
         match self {
-            Self::Node(cmd) => cmd.run(),
-            Self::Python(cmd) => cmd.run(),
-            Self::Ruby(cmd) => cmd.run(),
+            Self::Node(cmd) => cmd.run().await,
+            Self::Python(cmd) => cmd.run().await,
+            Self::Ruby(cmd) => cmd.run().await,
         }
     }
 }
 
 impl Sync {
-    pub fn run(self) -> Result<()> {
-        self.command.run()
+    pub async fn run(self) -> Result<()> {
+        self.command.run().await
     }
 }
