@@ -2,10 +2,7 @@ use crate::Result;
 use crate::env_diff::{EnvDiff, EnvDiffOperation, EnvDiffPatches, EnvMap};
 use crate::file::replace_path;
 use crate::shell::ShellType;
-use crate::{
-    cli::args::{ENV_ARG, PROFILE_ARG, ToolArg},
-    file::display_path,
-};
+use crate::{cli::args::ToolArg, file::display_path};
 use eyre::Context;
 use indexmap::IndexSet;
 use itertools::Itertools;
@@ -324,6 +321,8 @@ pub static MISE_NODE_MAKE_INSTALL_OPTS: Lazy<Option<String>> = Lazy::new(|| {
         .or_else(|_| var("NODE_MAKE_INSTALL_OPTS"))
         .ok()
 });
+pub static MISE_JOBS: Lazy<Option<usize>> =
+    Lazy::new(|| var("MISE_JOBS").ok().and_then(|v| v.parse::<usize>().ok()));
 pub static MISE_NODE_DEFAULT_PACKAGES_FILE: Lazy<PathBuf> = Lazy::new(|| {
     var_path("MISE_NODE_DEFAULT_PACKAGES_FILE").unwrap_or_else(|| {
         let p = HOME.join(".default-nodejs-packages");
@@ -491,16 +490,12 @@ fn prefer_offline(args: &[String]) -> bool {
 }
 
 fn environment(args: &[String]) -> Vec<String> {
-    let arg_defs = HashSet::from([
-        format!("--{}", PROFILE_ARG.get_long().unwrap_or_default()),
-        format!("-{}", PROFILE_ARG.get_short().unwrap_or_default()),
-        format!("--{}", ENV_ARG.get_long().unwrap_or_default()),
-        format!("-{}", ENV_ARG.get_short().unwrap_or_default()),
-    ]);
+    let arg_defs = HashSet::from(["--profile", "-P", "--env", "-E"]);
 
     args.windows(2)
+        .take_while(|window| !window.iter().any(|a| a == "--"))
         .find_map(|window| {
-            if arg_defs.iter().contains(&window[0]) {
+            if arg_defs.contains(&*window[0]) {
                 Some(window[1].clone())
             } else {
                 None
@@ -580,7 +575,7 @@ mod tests {
 
     #[tokio::test]
     async fn test_apply_patches() {
-        let _config = Config::get().await;
+        let _config = Config::get().await.unwrap();
         let mut env = EnvMap::new();
         env.insert("foo".into(), "bar".into());
         env.insert("baz".into(), "qux".into());
@@ -597,7 +592,7 @@ mod tests {
 
     #[tokio::test]
     async fn test_var_path() {
-        let _config = Config::get().await;
+        let _config = Config::get().await.unwrap();
         set_var("MISE_TEST_PATH", "/foo/bar");
         assert_eq!(
             var_path("MISE_TEST_PATH").unwrap(),
