@@ -22,7 +22,7 @@ use walkdir::WalkDir;
 use zip::ZipArchive;
 
 #[cfg(windows)]
-use crate::config::SETTINGS;
+use crate::config::Settings;
 use crate::ui::progress_report::SingleReport;
 use crate::{dirs, env};
 
@@ -391,11 +391,14 @@ pub fn make_symlink_or_file(target: &Path, link: &Path) -> Result<()> {
     Ok(())
 }
 
-pub fn resolve_symlink(link: &Path) -> Result<PathBuf> {
+pub fn resolve_symlink(link: &Path) -> Result<Option<PathBuf>> {
+    if !link.is_symlink() {
+        return Ok(None);
+    }
     if cfg!(windows) {
-        Ok(fs::read_to_string(link)?.into())
+        Ok(Some(fs::read_to_string(link)?.into()))
     } else {
-        Ok(fs::read_link(link)?)
+        Ok(Some(fs::read_link(link)?))
     }
 }
 
@@ -438,12 +441,12 @@ pub fn is_executable(path: &Path) -> bool {
 #[cfg(windows)]
 pub fn is_executable(path: &Path) -> bool {
     path.extension().map_or(
-        SETTINGS
+        Settings::get()
             .windows_executable_extensions
             .contains(&String::new()),
         |ext| {
             if let Some(str_val) = ext.to_str() {
-                return SETTINGS
+                return Settings::get()
                     .windows_executable_extensions
                     .contains(&str_val.to_lowercase().to_string());
             }
@@ -809,13 +812,14 @@ pub fn same_file(a: &Path, b: &Path) -> bool {
 }
 
 pub fn desymlink_path(p: &Path) -> PathBuf {
-    if let Ok(target) = fs::read_link(p) {
-        target
-            .canonicalize()
-            .unwrap_or_else(|_| target.to_path_buf())
-    } else {
-        p.canonicalize().unwrap_or_else(|_| p.to_path_buf())
+    if p.is_symlink() {
+        if let Ok(target) = fs::read_link(p) {
+            return target
+                .canonicalize()
+                .unwrap_or_else(|_| target.to_path_buf());
+        }
     }
+    p.canonicalize().unwrap_or_else(|_| p.to_path_buf())
 }
 
 pub fn clone_dir(from: &PathBuf, to: &PathBuf) -> Result<()> {
@@ -839,7 +843,7 @@ mod tests {
 
     #[tokio::test]
     async fn test_find_up() {
-        let _config = Config::get().await;
+        let _config = Config::get().await.unwrap();
         let path = &env::current_dir().unwrap();
         let filenames = vec![".miserc", ".mise.toml", ".test-tool-versions"]
             .into_iter()
@@ -857,7 +861,7 @@ mod tests {
 
     #[tokio::test]
     async fn test_find_up_2() {
-        let _config = Config::get().await;
+        let _config = Config::get().await.unwrap();
         let path = &dirs::HOME.join("fixtures");
         let filenames = vec![".test-tool-versions"];
         let result = find_up(path, &filenames);
@@ -866,7 +870,7 @@ mod tests {
 
     #[tokio::test]
     async fn test_dir_subdirs() {
-        let _config = Config::get().await;
+        let _config = Config::get().await.unwrap();
         let subdirs = dir_subdirs(&dirs::HOME).unwrap();
         assert!(subdirs.contains("cwd"));
     }
@@ -874,7 +878,7 @@ mod tests {
     #[tokio::test]
     #[cfg(unix)]
     async fn test_display_path() {
-        let _config = Config::get().await;
+        let _config = Config::get().await.unwrap();
         use std::ops::Deref;
         let path = dirs::HOME.join("cwd");
         assert_eq!(display_path(path), "~/cwd");
@@ -887,7 +891,7 @@ mod tests {
 
     #[tokio::test]
     async fn test_replace_path() {
-        let _config = Config::get().await;
+        let _config = Config::get().await.unwrap();
         assert_eq!(replace_path(Path::new("~/cwd")), dirs::HOME.join("cwd"));
         assert_eq!(replace_path(Path::new("/cwd")), Path::new("/cwd"));
     }
